function vseconde = fr_auth (file,t,vprime,C_Taille, save,verbose)
%
% Fr_auth crée un signature quand un usager est pris en photo (file)
%   et qu'il fourni sa clé privée vprime qu'il saisit (en parmatère). 
%   cette singaute est donc fait grace a sa photo .pgm.oct, sa clé privee
%   et la clé publique t, le vecteur de EigenFaces.
%
%		file : nom du fichier pgm.oct à authentifier 
%		t    : vecteur EigenFaces
%		vprime : vecteur clé privée à vérifier
%		C_Taille : ceci est une contrainte (repr X*Y) 
%		vseconde : Valeur Renvoyée. La clé privée de l'usager
%		(dans l'ideal doit etre egal à vprime)  
%
%		DEBUG FLAGS
%		save    : mis a 1 cela sauve de l'environnement
%			   (dans le fichier auth.save)
%		verbose : mis a 1 cela affiche les resultats intermédiares
%
%	Auteur 	: Mathieu Deschamps
%		  mathdesc@scourge.fr
%	Date	: 11/02/2004 
%	IUT de Caen -- Licence Pro. M.C.A
%

cmd=sprintf("load -force %s",file);file
eval(cmd) 
if (dims(1)*dims(2)!=C_Taille) 
			printf("%s: La taille de l'image [%i,%i] et le paramétre \nde la fonction %i doivent correspondre !\n",file,dims(1),dims(2),C_Taille); 
end

yseconde=reshape(X,dims(1)*dims(2),1);
ysecondec=yseconde-ones(dims(1)*dims(2),1)*ncol/2;

if (verbose==1)
 vseconde=cov(t,yseconde)
else
 vseconde=cov(t,yseconde);
end

if (save==1)
	save "auth.save";
end
printf("Clé privée à authentifier générée...\n"); 

